@@ -4,7 +4,7 @@ package Mail::AuthenticationResults::Header::Base;
 require 5.008;
 use strict;
 use warnings;
-our $VERSION = '2.20230112'; # VERSION
+our $VERSION = '2.20260216'; # VERSION
 use Scalar::Util qw{ weaken refaddr };
 use JSON;
 use Carp;
@@ -13,6 +13,11 @@ use Clone qw{ clone };
 use Mail::AuthenticationResults::Header::Group;
 use Mail::AuthenticationResults::FoldableHeader;
 
+use Mail::AuthenticationResults::Header::Entry;
+use Mail::AuthenticationResults::Header::SubEntry;
+use Mail::AuthenticationResults::Header::Comment;
+
+
 
 sub _HAS_KEY{ return 0; }
 sub _HAS_VALUE{ return 0; }
@@ -100,8 +105,10 @@ sub stringify {
     my ( $self, $value ) = @_;
     my $string = $value;
     $string = q{} if ! defined $string; #5.8;
+    my $strict_quotes = $self->strict_quotes;
 
-    if ( $string =~ /[\s\t \(\);=]/ ) {
+    if (  (  $strict_quotes && $string =~ /[\s\t \(\);=<>@,:\\\/\[\]\?]/ )
+       || ( !$strict_quotes && $string =~ /[\s\t \(\);=]/ ) ) {
         $string = '"' . $string . '"';
     }
 
@@ -197,6 +204,30 @@ sub add_child {
 }
 
 
+sub add_entry {
+    my ($self, $key, $value) = @_;
+    my $child = Mail::AuthenticationResults::Header::Entry->new->set_key($key)->safe_set_value($value);
+    $self->add_child($child);
+    return $child;
+}
+
+
+sub add_sub_entry {
+    my ($self, $key, $value) = @_;
+    my $child = Mail::AuthenticationResults::Header::SubEntry->new->set_key($key)->safe_set_value($value);
+    $self->add_child($child);
+    return $child;
+}
+
+
+sub add_comment {
+    my ($self, $value) = @_;
+    my $child = Mail::AuthenticationResults::Header::Comment->new->safe_set_value($value);
+    $self->add_child($child);
+    return $child;
+}
+
+
 sub ancestor {
     my ( $self ) = @_;
 
@@ -213,6 +244,24 @@ sub ancestor {
 }
 
 
+sub strict_quotes {
+    my ( $self ) = @_;
+
+    return $self->{ 'strict_quotes' } if defined $self->{ 'strict_quotes' };
+
+    my ( $eldest, $depth ) = $self->ancestor();
+    return 0 if $depth == 0;
+    return $eldest->strict_quotes;
+}
+
+
+sub set_strict_quotes {
+    my ( $self, $value ) = @_;
+    $self->{ 'strict_quotes' } = $value ? 1 : 0;
+    return $self;
+}
+
+
 sub as_string_prefix {
     my ( $self, $header ) = @_;
 
@@ -426,7 +475,7 @@ Mail::AuthenticationResults::Header::Base - Base class for modelling parts of th
 
 =head1 VERSION
 
-version 2.20230112
+version 2.20260216
 
 =head1 DESCRIPTION
 
@@ -567,10 +616,46 @@ Adds $child as a child of this instance.
 
 Croaks if the relationship between $child and $self is not valid.
 
+=head2 add_entry ($key, $value)
+
+Creates a new entry with the given key and value, and then adds
+that as a child.
+
+Returns the child added.
+
+=head2 add_sub_entry ($self, $key, $value)
+
+Creates a new sub entry with the given key and value, and then adds
+that as a child.
+
+Returns the child added.
+
+=head2 add_comment ($key, $value)
+
+Creates a new comment with the given key and value, and then adds
+that as a child.
+
+Returns the child added.
+
 =head2 ancestor()
 
 Returns the top Header object and depth of this child
 
+=head2 strict_quotes()
+
+Return the current value of strict quotes flag for this header or for its
+ancestor if not set locally
+
+If true, we are stricter about which characters result in a quoted string
+
+=head2 set_strict_quotes( $value )
+
+Set the value of strict quotes
+
+If true, we are stricter about which characters result in a quoted string
+
+Default false
+
 =head2 as_string_prefix( $header )
 
 Add the prefix to as_string for this object when calledas a child
